@@ -17,11 +17,9 @@ int MAIN(int Argc, char *Argv[])
 /*  ----------  */
 {
   RRuleSet *CubistModel;
-  double pval;
   FILE *F;
   int o;
-  extern String OptArg, Option;
-  CaseNo i;
+  extern String OptArg;
 
   /*  Process options  */
 
@@ -84,17 +82,6 @@ int MAIN(int Argc, char *Argv[])
 
   FindPredictedValues(CubistModel, 0, MaxCase);
 
-  /* commented out to pass R CMD check: "Compiled code should
-         [...]  write to stdout/stderr instead of to the console" */
-  /* printf("predicted values:\n"); */
-
-  ForEach(i, 0, MaxCase) {
-    pval = PredVal(Case[i]);
-    /* commented out to pass R CMD check: "Compiled code should
-       [...]  write to stdout/stderr instead of to the console" */
-    /* printf("%f\n", pval); */
-  }
-
   /* Free memory allocated by GetCommittee */
   FreeCttee(CubistModel);
   CubistModel = Nil;
